@@ -6,19 +6,15 @@ OC.L10N.register(
     "Contacts" : "Харилцагчид",
     "Copy to full name" : "Бүтэн нэр хуулах",
     "Loading …" : "Уншиж байна...",
-    "Add member" : "Гишүүн нэмэх",
-    "Delete circle" : "бүлгийг устгах",
-    "Circles" : "Тойрог",
-    "Create a new circle" : "шинэ бүлэг үүсгэх",
-    "Download" : "Татаж авах",
     "Rename" : "Нэр солих",
-    "Enabled" : "Идэвхижүүлэх",
     "Delete" : "Устгах",
     "Copied" : "Хуулагдсан",
     "Cannot copy" : "Хуулагдаагүй",
     "Copy link" : "Холбоос хуулах",
+    "Download" : "Татаж авах",
     "Share with users or groups" : "Бусдад түгээх",
     "can edit" : "засаж чадна",
+    "Add" : "нэмэх",
     "First name" : "Нэр",
     "Last name" : "Овог",
     "Display name" : "Харагдах нэр",
@@ -26,25 +22,24 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Хадгалах",
     "Description" : "Тайлбар",
+    "Settings" : "Settings",
     "Cancel" : "болиулах",
+    "Invalid image" : "буруу зураг",
     "Upload a new picture" : "Шинэ зураг оруулах",
     "Choose from Files" : "Файлаас сонгох",
     "Download picture" : "Зураг татаж авах",
     "Delete picture" : "Зураг устгах",
-    "Invalid image" : "буруу зураг",
+    "Address book" : "Хаягийн бүртгэл",
     "Name" : "Нэр",
     "Title" : "Цол/Албан тушаал",
     "Select address book" : "Хаягийн бүртгэл сонгох",
-    "Address book" : "Хаягийн бүртгэл",
-    "New contact" : "Шинэ харилцагч",
     "No results" : "Үр дүн байхгүй",
-    "Personal circle" : "Хувийн тойрог",
     "Pending" : "Хүлээгдэж байгаа",
     "None" : "юу ч үгүй",
+    "New contact" : "Шинэ харилцагч",
     "Close" : "Хаах",
     "Import" : "Импорт",
     "Not grouped" : "Багт ороогүй",
-    "Circle" : "Тойрог",
     "User" : "Хэрэглэгч",
     "Group" : "Бүлэг",
     "Email" : "Цахим шуудан",
@@ -52,7 +47,7 @@ OC.L10N.register(
     "Moderator" : "Шалгагч",
     "Admin" : "Админ",
     "Owner" : "Эзэмшигч",
-    "Users" : "хэрэглэгч",
+    "Groups" : "Багууд",
     "Detailed name" : "Дэлгэрэнгүй нэр",
     "Additional names" : "Нэмэлт нэрүүд",
     "Nickname" : "Товч нэр",
@@ -75,7 +70,6 @@ OC.L10N.register(
     "Fax" : "Факс",
     "Fax home" : "Гэрийн факс",
     "Fax work" : "Ажлын факс",
-    "Manager" : "Менежер",
     "Social network" : "Олон нийтийн сүлжээ",
     "Child" : "хүүхэд",
     "Mother" : "эх",
@@ -90,6 +84,7 @@ OC.L10N.register(
     "Female" : "Эмэгтэй",
     "Male" : "Эрэгтэй",
     "Unknown" : "Үл танигдах зүйл",
-    "Time zone" : "Цагийн бүс"
+    "Time zone" : "Цагийн бүс",
+    "Manager" : "Менежер"
 },
 "nplurals=2; plural=(n != 1);");
